KPrint

Struct KPrint 

#[repr(align(64))]
pub struct KPrint { lockable: IrqMutex<KPrintState>, config: KPrintConfig, }
A struct which goes into KSTATE and contains an IrqMutex wrapped KPrintState and the current max_log_level and log_targets as [AtomicU8]s

Fields

lockable: IrqMutex<KPrintState>config: KPrintConfig

Implementations

Source

impl KPrint

pub const fn new() -> Self

Constructor; creates a new KPrint instance with zeroed values. Init needs to be called before using any values in this struct to set the proper default values

pub fn init(&self)

Initialize self.config to its correct default values

pub fn lock(&self) -> IrqMutexGuard<'_, KPrintState>

Locks and returns an IrqMutexGuard of KPrintState

pub fn config(&self) -> &KPrintConfig

Getter for self.config